from distutils.core import setup

long_description = ''

setup(name='summarise',
      version='0.0.3',
      description='Text Summarisation for Python',
      long_description=long_description,
      url='https://www.github.com/bonzanini/summarise',
      author='Marco Bonzanini',
      author_email='marco.bonzanini@gmail.com',
      license='MIT')

